tdub.ml_train
-------------

A module for handling training

.. currentmodule:: tdub.ml_train

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   prepare_from_root
   folded_training
   single_training

Reference
^^^^^^^^^

.. autofunction:: prepare_from_root
.. autofunction:: folded_training
.. autofunction:: single_training
